#!/bin/bash
clear
echo "***************************************************"
echo "**     Avaya /boot partition cleanup script      **"
echo "***************************************************"
echo 

if [ "$(id -u)" != "0" ]; then
    echo "This script must be run as root.Please login as root and try again."
    exit 1
fi

echo "Checking /boot partition free space ..."
freeSpace=`stat -f --printf="%a * %s / 1024\n" /boot | bc`
requiredSpace=18000
nr_kernels=`rpm -q kernel | wc -l`
if [ $freeSpace -le $requiredSpace -o $nr_kernels -ge 2 ]; then
    if [ $nr_kernels -ge 2 ]; then
        echo "This system has the boot partition too small for an kernel upgrade or some kernels should be removed"
        echo "Start /boot partition cleanup ? Please type the 'yes',followed by [ENTER]:"
        read answer
        if [ "$answer" == "yes" ]; then
            package-cleanup --oldkernels --count=1 -y
            newfreeSpace=`stat -f --printf="%a * %s / 1024\n" /boot | bc`
            if [ $newfreeSpace -le $requiredSpace ]; then
                echo "Removed some kernels, but boot partition still doesn't have enough space."
                echo "Please check /boot partition if contains unwanted files, and if not raise an issue."
            else
                echo "Success"
            fi
        else
            echo "Exit."
        fi
    else
        echo "Error: There are only $nr_kernels kernels installed, this procedure should not be needed."
        echo "Please check /boot partition if contains unwanted files, and if not raise an issue."
    fi
else
    echo "There is enough space on the /boot partition, if upgrade doesn't work please raise an issue."
fi
exit 0

